%
% utlsethesis: LaTeX  thesis document class including  a  preset
% theme coloured according  to the French university of Toulouse
% style.
%                                                                  
% Copyright © 2010 by Jean-Sébastien Kroll-Rabotin
%                       <jeansebastien.krollrabotin@ensiacet.fr>
% 
% This program is free software;  you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 3 of
% the License, or (at your option) any later version. 
%                                                                  
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or  FITNESS FOR A  PARTICULAR PURPOSE. See the
% GNU General Public License for more details.
%                                                                  
% May/23/2011  File created (based on jskthesis)	..ver 0.1


%%% BUILDS WITH LaTeX, pdfLaTeX AND XeLaTeX
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{utlsethesis}%[2010-05-18]
\LoadClassWithOptions{book}

%%% BUILD PDF AND POSTSCRIPTS FROM THE SAME TEX SOURCE
\RequirePackage{ifpdf}
\ifpdf
	%%% PACKAGES LOADED WITH PDF OPTIONS
	\RequirePackage[pdftex,bookmarks=true,bookmarksnumbered=true,
			hypertexnames=false,colorlinks=true]{hyperref}
	\RequirePackage[pdftex]{graphicx}
	\DeclareGraphicsExtensions{.pdf,.png,.jpg}
	\PassOptionsToPackage{pdftex}{geometry}
\else
	\RequirePackage{ifxetex}
	\ifxetex
		%%% PACKAGES LOADED WITH PDF OPTIONS
		\RequirePackage[xetex,bookmarks=true,bookmarksnumbered=true,
				hypertexnames=false,colorlinks=true]{hyperref}
		\RequirePackage[xetex]{graphicx}
		\DeclareGraphicsExtensions{.pdf,.png,.jpg}
		\PassOptionsToPackage{pdftex}{geometry}
	\else
		%%% PACKAGES LOADED WITH POSTSCRIPT OPTIONS
		\RequirePackage[dvips,linktocpage]{hyperref}
		\RequirePackage[dvips]{graphicx}
		\DeclareGraphicsExtensions{.eps}
		\PassOptionsToPackage{dvips}{geometry}
	\fi
\fi 
\RequirePackage{xcolor}
\RequirePackage{ifthen}
	\newboolean{utlse@review}
	\newboolean{utlse@chapterlines}
	\newboolean{utlse@outernum}
	\newboolean{utlse@skin}
	\newboolean{utlse@chapterbib}
	\newboolean{utlse@nofancy}
	\newboolean{utlse@pagemarks}
	\newboolean{utlse@autochaptermark}
	\newboolean{utlse@geometry}

\DeclareOption{review}{\setboolean{utlse@review}{true}}
\DeclareOption{chapterlines}{\setboolean{utlse@chapterlines}{true}}
\DeclareOption{outernum}{\setboolean{utlse@outernum}{true}}
\DeclareOption{skin}{\setboolean{utlse@skin}{true}}
\DeclareOption{chapterbib}{\setboolean{utlse@chapterbib}{true}}
\DeclareOption{nofancy}{\setboolean{utlse@nofancy}{true}}
\DeclareOption{pagemarks}{\setboolean{utlse@pagemarks}{true}}
\DeclareOption{autochaptermark}{\setboolean{utlse@autochaptermark}{true}}
% natbib options (when using chapterbib class option, there is no other way to set them than via class options too)}
\DeclareOption{natround}{\PassOptionsToPackage{round}{natbib}}
\DeclareOption{natsquare}{\PassOptionsToPackage{square}{natbib}}
\DeclareOption{natcurly}{\PassOptionsToPackage{curly}{natbib}}
\DeclareOption{natangle}{\PassOptionsToPackage{angle}{natbib}}
\DeclareOption{natcolon}{\PassOptionsToPackage{colon}{natbib}}
\DeclareOption{natcomma}{\PassOptionsToPackage{comma}{natbib}}
\DeclareOption{natauthoryear}{\PassOptionsToPackage{authoryear}{natbib}}
\DeclareOption{natnumbers}{\PassOptionsToPackage{numbers}{natbib}}
\DeclareOption{natsuper}{\PassOptionsToPackage{super}{natbib}}
\DeclareOption{natsort}{\PassOptionsToPackage{sort}{natbib}}
\DeclareOption{natsort&compress}{\PassOptionsToPackage{sort&compress}{natbib}}
\DeclareOption{natlongnamesfirst}{\PassOptionsToPackage{longnamesfirst}{natbib}}
\DeclareOption{natsectionbib}{\PassOptionsToPackage{sectionbib}{natbib}}
\DeclareOption{natnonamebreak}{\PassOptionsToPackage{nonamebreak}{natbib}}
\DeclareOption{geometry}{\setboolean{utlse@geometry}{true}}

\ProcessOptions

\setlength{\emergencystretch}{3em}

\ifthenelse{\boolean{utlse@chapterlines}}{
	\RequirePackage{lineno} % Line numbering while reviewing

	%%% LINENO FIX
	\newcommand*\patchAmsMathEnvironmentForLineno[1]{%
	  \expandafter\let\csname utlse@fix#1\expandafter\endcsname\csname #1\endcsname
          \expandafter\let\csname utlse@fixend#1\expandafter\endcsname\csname end#1\endcsname
	  \renewenvironment{#1}%
	     {\linenomath\csname utlse@fix#1\endcsname}%
	     {\csname utlse@fixend#1\endcsname\endlinenomath}}% 
	\newcommand*\patchBothAmsMathEnvironmentsForLineno[1]{%
	  \patchAmsMathEnvironmentForLineno{#1}%
          \patchAmsMathEnvironmentForLineno{#1*}}%
	\AtBeginDocument{%
		\@ifpackageloaded{amsmath}{
			\patchBothAmsMathEnvironmentsForLineno{equation}%
			\patchBothAmsMathEnvironmentsForLineno{align}%
			\patchBothAmsMathEnvironmentsForLineno{flalign}%
        		\patchBothAmsMathEnvironmentsForLineno{alignat}%
			\patchBothAmsMathEnvironmentsForLineno{gather}%
			\patchBothAmsMathEnvironmentsForLineno{multline}%
		}{}
	}
}{}

\ifthenelse{\boolean{utlse@review} \and \boolean{utlse@chapterlines}}{% 
	\renewcommand\thelinenumber{
		\ifthenelse{\value{linenumber} > 0}{% 
			\arabic{linenumber}
		}{\phantom{\arabic{linenumber}}}
	}
}{}

%\clearpage{\pagestyle{plain}\cleardoublepage}

\let\utlse@oldpart=\part

\renewcommand\part{%
	\clearpage\if@twoside{\pagestyle{empty}\cleardoublepage}\fi
	\utlse@oldpart
}

\ifthenelse{\boolean{utlse@pagemarks} \and \boolean{utlse@autochaptermark} \and \not \boolean{utlse@nofancy}}{%
	\newcommand{\utlse@setchapterpagemark}{\setpagemark{\@chapapp\nobreakspace\thechapter}}
	\newcommand{\utlse@unsetchapterpagemark}{\unsetpagemark}
}{%
	\newcommand{\utlse@setchapterpagemark}{}
	\newcommand{\utlse@unsetchapterpagemark}{}
}

%\renewcommand{\thechapter}{\Roman{chapter}}

\renewcommand\chapter{
	\clearpage\if@twoside{\pagestyle{empty}\cleardoublepage}\fi
	%\if@openright\cleardoublepage\else\clearpage\fi
	\thispagestyle{empty}%
	\global\@topnum\z@
	\ifthenelse{\boolean{utlse@review} \and \boolean{utlse@chapterlines}}{% 
		\linenumbers[-2]
	}{}
	\@afterindentfalse
	\utlse@unsetchapterpagemark
	\secdef{\utlse@setchapterpagemark\@chapter}\@schapter
}

%\let\utlse@oldpart=\part
%
%\renewcommand\part{%
%	\utlse@oldpart
%}

\newfont{\chapterNumberFont}{\rmdefault10 scaled 7000}%

\newlength{\chapterWidth}
\newlength{\chapterrulethickness}
\newlength{\inmarginnumbering}
\newlength{\chapterspacing}
\newlength{\chapTitleWidth}
\newlength{\chapNumberWidth}

\newcommand{\chapterStyle}{\raggedright\Huge\sc}
\newcommand{\chapterNumberStyle}{}

\renewcommand{\thepart}{\Roman{part}}%

\newcommand{\partStyle}{\Huge\sc}
\newcommand{\partHeaderStyle}{\huge}

\def\@part[#1]#2{
	\ifnum \c@secnumdepth >-2\relax
		\refstepcounter{part}%
	\fi
	\addcontentsline{toc}{part}{#1}%
	\ifthenelse{\boolean{utlse@review} \and \boolean{utlse@chapterlines}}{% 
		\linenumbers[-2]
	}{}
	\thispagestyle{empty}%
	\markboth{}{}%
	{\centering
	\interlinepenalty \@M
	\normalfont
	\ifnum \c@secnumdepth >-2\relax
		\partHeaderStyle \partname\nobreakspace\thepart
		\par
		\vskip 20\p@
	\fi
	\partStyle #2\par}%
	\@endpart
}

\renewcommand{\@spart}[2]{%
	\ifnum \c@secnumdepth >-2\relax
		\refstepcounter{part}%
	\fi
	\addcontentsline{toc}{part}{#1}%
	\ifthenelse{\boolean{utlse@review} \and \boolean{utlse@chapterlines}}{% 
		\linenumbers[-2]
	}{}
	\thispagestyle{empty}%
	{\centering
	\interlinepenalty \@M
	\normalfont
	\partStyle #1\par}%
	\@endpart
}


\ifthenelse{\boolean{utlse@outernum} \and \not \boolean{utlse@geometry}}{% 
	\renewcommand{\@makechapterhead}[1]{{%
		\setlength{\chapterWidth}{\textwidth}
		\addtolength{\chapterWidth}{\inmarginnumbering}
		\addtolength{\chapterWidth}{\marginparwidth}
		\addtolength{\chapterWidth}{\marginparsep}
		\vspace*{\sidemargin}
		\raggedright
		\settowidth{\chapNumberWidth}{\hspace*{\chapterspacing}\chapterNumberStyle{\chapterNumberFont\thechapter}}
		\setlength{\chapTitleWidth}{\chapterWidth}
		\addtolength{\chapTitleWidth}{-\chapNumberWidth}
		\addtolength{\chapTitleWidth}{-1em}
		\parbox{\chapterWidth}{%
			\parbox[b][][t]{\chapTitleWidth}{\chapterStyle #1}
			\hfill
			\ifnum \c@secnumdepth >\m@ne
				\parbox[t][][t]{\chapNumberWidth}{%
					{\hspace*{\chapterspacing}\chapterNumberStyle{\chapterNumberFont\thechapter}}
				}
			\fi
		}\hspace*{-\inmarginnumbering}\hspace*{-1em}
		\par
		\vspace*{1em}
		\rule{\chapterWidth}{\chapterrulethickness}\hspace*{-\inmarginnumbering}
		\nobreak
		\vskip 40\p@
	}}
	\renewcommand{\@makeschapterhead}[1]{{%
		\setlength{\chapterWidth}{\textwidth}
		\addtolength{\chapterWidth}{\inmarginnumbering}
		\vspace*{\sidemargin}
		\raggedright
		\setlength{\chapNumberWidth}{0pt}
		\setlength{\chapTitleWidth}{\textwidth}
		\parbox[c][][t]{\chapTitleWidth}{\chapterStyle #1}
		\par
		\vspace*{1em}
		\rule{\chapterWidth}{\chapterrulethickness}\hspace*{-\inmarginnumbering}
		\nobreak
		\vskip 40\p@
	}}
}{%
	\renewcommand{\@makechapterhead}[1]{{%
		\setlength{\chapterWidth}{\textwidth}
		\addtolength{\chapterWidth}{\inmarginnumbering}
	%	\addtolength{\chapterWidth}{\marginparwidth}
	%	\addtolength{\chapterWidth}{\marginparsep}

		\ifthenelse{\boolean{utlse@geometry}}{
		}{
			\vspace*{\sidemargin}
		}

		\raggedright
		\settowidth{\chapNumberWidth}{\hspace*{\chapterspacing}\chapterNumberStyle{\chapterNumberFont\thechapter}}
		\setlength{\chapTitleWidth}{\chapterWidth}
		\addtolength{\chapTitleWidth}{-\chapNumberWidth}
		\addtolength{\chapTitleWidth}{-1em}
		\hspace*{-\inmarginnumbering}
		\parbox{\chapterWidth}{%
			\ifnum \c@secnumdepth >\m@ne
				\parbox[c][][t]{\chapNumberWidth}{%
					{\chapterNumberStyle{\chapterNumberFont\thechapter}\hspace*{\chapterspacing}}
				}
			\fi
			\hfill
			\parbox[c][][t]{\chapTitleWidth}{\chapterStyle #1}
		}\hspace*{-1em}
		\par
		\vspace*{1em}
		\hspace*{-\inmarginnumbering}\rule{\chapterWidth}{\chapterrulethickness}
		\nobreak
		\vskip 40\p@
	}}
	\renewcommand{\@makeschapterhead}[1]{{%
		\setlength{\chapterWidth}{\textwidth}
		\addtolength{\chapterWidth}{\inmarginnumbering}

		\ifthenelse{\boolean{utlse@geometry}}{
		}{
			\vspace*{\sidemargin}
		}

		\raggedright
		\setlength{\chapNumberWidth}{0pt}
		\setlength{\chapTitleWidth}{\textwidth}
		\parbox[c][][t]{\chapTitleWidth}{\chapterStyle #1}
		\par
		\vspace*{1em}
		\hspace*{-\inmarginnumbering}\rule{\chapterWidth}{\chapterrulethickness}
		\nobreak
		\vskip 40\p@
	}}
}

\newcommand{\sectionStyle}{\raggedright\Large\sc}
\renewcommand\section{\@startsection{section}{1}{\z@}%
                                   {-3.5ex \@plus -1ex \@minus -.2ex}%
                                   {2.3ex \@plus.2ex}%
                                   {\sectionStyle}}
\renewcommand\thesection{\arabic{section}}

\newcommand{\subsectionStyle}{\raggedright\large\sc}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
				{-3.25ex\@plus -1ex \@minus -.2ex}%
				{1.5ex \@plus .2ex}%
				{\subsectionStyle}}
\renewcommand\thesubsection{\thesection.\arabic{subsection}}

\newcommand{\subsubsectionStyle}{\raggedright\normalsize\sc}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
				{-3.25ex\@plus -1ex \@minus -.2ex}%
				{1.5ex \@plus .2ex}%
				{\subsubsectionStyle}}
\renewcommand\thesubsubsection{\thesubsection.\arabic{subsubsection}}

\newcommand{\paragraphStyle}{\it}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
				{-3.25ex\@plus -1ex \@minus -.2ex}%
				{.5ex \@plus .2ex}%
				{\paragraphStyle}}

\newcommand{\subparagraphStyle}{\it}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
				{3.25ex \@plus1ex \@minus .2ex}%
				{-1em}%
				{\subparagraphStyle}}

\ifthenelse{\boolean{utlse@review}}{% 
	\linespread{2.10}
	\overfullrule=5pt
}{}

\hypersetup{
	linkcolor 	=black, % color of internal links (sect., pages, ...)
	citecolor 	=black, % color of citation links (bibliography)
	filecolor 	=black, % color of file links
	urlcolor 	=black, % color of URL links (mail, web)
	%pdffitwindow = true,
	pdfsubject  = {},
	pdfkeywords = {},
	%pdfpagemode = {UseThumbs}
}

\AtBeginDocument{
\hypersetup{
	pdfauthor   = {\@author},
	pdftitle    = {\@title},
}}

%%% PAGE LAYOUT

\newlength{\abstractrulethickness}
\setlength{\abstractrulethickness}{.8pt}

\ifthenelse{\boolean{utlse@geometry}}{
	\newcommand{\setlayout}[2]{}
	\newcommand{\computepagelayout}{}

}{
	\PassOptionsToPackage{pass}{geometry}

	\newlength{\footsep}
	\newlength{\footheight}
	\newlength{\bottommargin}
	\newlength{\sidemargin}
	\newlength{\bindingwidth}

	\setlength{\topmargin}{2cm}
	\setlength{\headheight}{3.5em}
	\setlength{\headsep}{1cm}
	\setlength{\sidemargin}{3.5cm}
	\setlength{\marginparwidth}{0cm}
	\setlength{\marginparsep}{0cm}
	\if@twoside
		\setlength{\bindingwidth}{1cm}
	\else
		\setlength{\bindingwidth}{0cm}
	\fi
	\setlength{\inmarginnumbering}{.65\sidemargin}
	\setlength{\chapterrulethickness}{1pt}
	\setlength{\chapterspacing}{1cm}

	\setlength{\bottommargin}{\sidemargin}
	\setlength{\footheight}{0pt}
	\setlength{\footsep}{0pt}

	\newcommand{\computepagelayout}{
		\setlength{\voffset}{-1in}
		\setlength{\footskip}{\footheight}
		\addtolength{\footskip}{\footsep}
		\setlength{\textheight}{\paperheight}
		\addtolength{\textheight}{-\headheight}
		\addtolength{\textheight}{-\headsep}
		\addtolength{\textheight}{-\topmargin}
		\addtolength{\textheight}{-\footsep}
		\addtolength{\textheight}{-\footheight}
		\addtolength{\textheight}{-\bottommargin}
		
		\setlength{\hoffset}{-1in}
		\setlength{\evensidemargin}{\sidemargin}
		\setlength{\oddsidemargin}{\sidemargin}
		%\if@twoside %%% Oddsidemargin is the left margin in oneside mode, it is valid for both oneside and twoside modes
			\addtolength{\oddsidemargin}{\bindingwidth}
		%\fi
		\addtolength{\evensidemargin}{\marginparsep}
		\addtolength{\evensidemargin}{\marginparwidth}
		\setlength{\textwidth}{\paperwidth}
		\addtolength{\textwidth}{-\sidemargin}
		\addtolength{\textwidth}{-\sidemargin}
		\addtolength{\textwidth}{-\marginparsep}
		\addtolength{\textwidth}{-\marginparwidth}
		\addtolength{\textwidth}{-\bindingwidth}
	}

	\newcommand{\setlayout}[2]{\setlength{#1}{#2}\computepagelayout}

	\ifthenelse{\boolean{utlse@nofancy}}{
		\AtBeginDocument{
			\pagestyle{plain}
		}

		\newcommand{\cleanmarks}{%
			\markboth{}{}
		}
		}{%
		\RequirePackage{fancyhdr}
		%
		\fancyhf{}
		\newcommand{\thechaptertitle}{}
		\newcommand{\thechapternumber}{}

		\newcommand{\thesectiontitle}{}
		\newcommand{\thesectionnumber}{}

		\newcommand{\thesubsectiontitle}{}
		\newcommand{\thesubsectionnumber}{}

		\newcommand{\utlse@thesectionnumber}{0}
		\newcommand{\utlse@thesubsectionnumber}{0}
		\renewcommand{\headrulewidth}{\chapterrulethickness} %%% fancyhdr

		%
		\AtBeginDocument{
			\pagestyle{fancy}
			\let\utlse@oldchaptermark=\chaptermark
			\def\chaptermark#1{%
				\utlse@oldchaptermark{#1}
				\renewcommand{\thechaptertitle}{#1}
				\edef\thechapternumber{\arabic{chapter}}
				%\renewcommand{\thesection}{}
				\sectionmark{}
			}
			
			\let\utlse@oldsectionmark=\sectionmark
			\def\sectionmark#1{%
				\utlse@oldsectionmark{#1}
				\renewcommand{\thesectiontitle}{#1}
				\edef\thesectionnumber{\arabic{section}}
				\edef\utlse@thesectionnumber{\arabic{section}}
				%\renewcommand{\thesubsection}{}
				\subsectionmark{}
			}
			
			\def\subsectionmark#1{%
				\renewcommand{\thesubsectiontitle}{#1}
				\edef\thesubsectionnumber{\arabic{subsection}}
				\edef\utlse@thesubsectionnumber{\arabic{subsection}}
			}
			\if@twoside
				\fancyhf[HOR]{\thepage}
				\fancyhf[HEL]{\thepage}
				\fancyhf[HOL]{\parbox[c][\headheight][c]{.8\linewidth}{%
					\ifthenelse{\utlse@thesectionnumber > 0}{%
						{\normalsize\raggedright\thesectionnumber\hspace{.5em}\thesectiontitle}
						\ifthenelse{\utlse@thesubsectionnumber > 0}{%
							\\{\small\thesectionnumber.\thesubsectionnumber\hspace{.5em}\thesubsectiontitle}}
						}{}
					}{}
				}
				\fancyhf[HER]{\parbox[c][\headheight][c]{.8\linewidth}{\raggedleft\footnotesize\leftmark}}
			\else
				\fancyhf[HR]{\parbox[c][\headheight][c]{.47\linewidth}{%
					\ifthenelse{\utlse@thesectionnumber > 0}{%
						{\normalsize\raggedright\thesectionnumber\hspace{.5em}\thesectiontitle}
						\ifthenelse{\utlse@thesubsectionnumber > 0}{%
							\\{\small\thesubsectionnumber\hspace{.5em}\thesubsectiontitle}}
						}{}
					}{}
				}
				\fancyhf[HL]{%
					\parbox[c][\headheight][c]{.47\linewidth}{\raggedleft{}\sc\Roman{chapter}\hspace{.5em}\thechaptertitle}
				}
				\let\utlse@oldappendix=\appendix
				\renewcommand{\appendix}{
					\fancyhf[HL]{%
						\parbox[c][\headheight][c]{.47\linewidth}{\raggedleft{}\sc\Alph{chapter}\hspace{.5em}\thechaptertitle}
					}
					\utlse@oldappendix	
				}
				\fancyhf[FL]{}
				\fancyhf[FR]{}
				\fancyhf[FC]{\thepage}
			\fi
		}

		\newcommand{\cleanmarks}{%
			\markboth{}{}
			\renewcommand{\utlse@thesectionnumber}{0}
			\renewcommand{\utlse@thesubsectionnumber}{0}
		}
	} % fi utlse@nofancy

} % fi utlse@geometry

\computepagelayout

\newcommand{\copytolastpage}[2][Couverture]{%
#2

\AtEndDocument{%
\pagestyle{empty}

\if@twoside
\ifthenelse{\isodd{\thepage}}{
\strut
\clearpage
}{}
\fi
\clearpage


\pdfbookmark[0]{#1}{utlselastpage}

#2
}
}

\newcommand{\sidenote}[1]{\marginpar{\footnotesize\it #1}}

\newcounter{abstract}

\newenvironment{abstract}[1]{
	\addtocounter{abstract}{1}
	\begin{center}
	\begin{minipage}[t]{.9\linewidth}
	\begingroup
	\section*{#1}
	\pdfbookmark[1]{#1}{abstract\expandafter\arabic{abstract}}

	\noindent\rule{\linewidth}{\abstractrulethickness}\vspace{.5em}\\
}{
	\\\vspace{.5em}\rule{\linewidth}{\abstractrulethickness}
	\endgroup		
	\end{minipage}
	\end{center}

	%\thispagestyle{empty}
	\vfill
}

\ifthenelse{\boolean{utlse@chapterbib}}{
	\RequirePackage[sectionbib]{chapterbib}
	\RequirePackage{natbib}
	\let\utlse@oldbibliography=\bibliography
	\renewcommand{\bibliography}[1]{%
		\ifthenelse{\value{section} > 0}{% 
			\section{\refname}
		}{%
			\section*{\refname}
			\addcontentsline{toc}{section}{\refname}
		}

		\renewcommand\bibsection{}
		\utlse@oldbibliography{#1}
	}
}{}

%%% IF FANCYHDR IS AVAILABLE THEN CREATE NEW COMMANDS TO ADD MARKS ON OUTER SIDES OF PAGES FOR
%%% QUICK NAVIGATION IN THE THESIS
\providecommand*\LenToUnit[1]{#1\@gobble} %%% cf. eso-pic package
\ifthenelse{\boolean{utlse@nofancy} \or \boolean{utlse@geometry}}{
	\newcommand{\setpagemark}[1]{}
	\newcommand{\unsetpagemark}{}
}{
	\newcounter{pagemark}
	\setcounter{pagemark}{-1}
	\newboolean{utlse@pagemark}
	\newcommand{\thepargemark}{}
	\newcommand{\pagemarkStyle}{\bf}
	\newlength{\pagemarkHeight}
	\newlength{\pagemarkWidth}
	\newlength{\pagemarkOffset}
	\newlength{\pagemarkBetween}
	\setlength{\pagemarkHeight}{4cm}
	\setlength{\pagemarkWidth}{1cm}%.3\sidemargin}
	\setlength{\pagemarkOffset}{2cm}%-\topmargin}
	\setlength{\pagemarkBetween}{4cm}
	\definecolor{pagemarkbg}{rgb}{0,0,0}
	\definecolor{pagemarkfg}{rgb}{1,1,1}
	\newlength{\utlse@pagemarkpostop}%
	\newlength{\utlse@pagemarkposside}%
	\newcommand{\utlse@pargemarkangle}{}%
	
	\newcommand{\setpagemark}[1]{%
		\setboolean{utlse@pagemark}{true}
		\addtocounter{pagemark}{1}
		\renewcommand{\thepagemark}{#1}
	}
	
	\newcommand{\unsetpagemark}{%
		\setboolean{utlse@pagemark}{false}
		\renewcommand{\thepagemark}{}
	}
	
	\newcommand{\utlse@pagemarkBlob}[1]{%
		\setlength{\fboxsep}{0pt}%
		\colorbox{pagemarkbg}{%
			\parbox[t][\pagemarkWidth][c]{\pagemarkHeight}{\centering\textcolor{white}{\pagemarkStyle #1}}%
		}%
	}%

	\newcommand{\pagemarkR}{%
		\setlength{\fboxsep}{0pt}
		\ifthenelse{\boolean{utlse@pagemark}}{%
			\setlength{\utlse@pagemarkpostop}{\pagemarkOffset}%
			\addtolength{\utlse@pagemarkpostop}{\value{pagemark}\pagemarkBetween}%
			\addtolength{\utlse@pagemarkpostop}{\pagemarkHeight}%
			\setlength{\utlse@pagemarkposside}{\sidemargin}%
			\addtolength{\utlse@pagemarkposside}{-\pagemarkWidth}%
			\addtolength{\utlse@pagemarkposside}{\marginparsep}%
			\addtolength{\utlse@pagemarkposside}{\marginparwidth}%
			\begin{picture}(0,0)%
				\put(\LenToUnit{\utlse@pagemarkposside},-\LenToUnit{\utlse@pagemarkpostop}){%
					\rotatebox{90}{%
						\utlse@pagemarkBlob{\thepagemark}%
					}%
				}%
			\end{picture}%
		}{}%
	}

	\newcommand{\pagemarkL}{%
		\setlength{\fboxsep}{0pt}
		\ifthenelse{\boolean{utlse@pagemark}}{%
			\setlength{\utlse@pagemarkpostop}{\pagemarkOffset}%
			\addtolength{\utlse@pagemarkpostop}{\value{pagemark}\pagemarkBetween}%
			\setlength{\utlse@pagemarkposside}{\sidemargin}%
			\addtolength{\utlse@pagemarkposside}{\marginparsep}%
			\addtolength{\utlse@pagemarkposside}{\marginparwidth}%
			\begin{picture}(0,0)%
				\put(-\LenToUnit{\utlse@pagemarkposside},-\LenToUnit{\utlse@pagemarkpostop}){%
					\rotatebox{-90}{%
    						\utlse@pagemarkBlob{\thepagemark}%
					}%
				}%
			\end{picture}%
		}{}%
	}


	\ifthenelse{\boolean{utlse@pagemarks}}{%
		\AtBeginDocument{%
			\fancyhf[HOR]{\thepage\pagemarkR}
			\fancyhf[HEL]{\pagemarkL\thepage}
		}
	}
}

\ifthenelse{\boolean{utlse@review}}{
	\newcommand{\openingpic}[1]{}
	\newcommand{\fullpagepic}[2][]{\clearpage}
}{
	\newlength{\utlse@openingpicturewidth}
	\newlength{\utlse@openingbottommargin}
	\newcommand{\openingpic}[1]{%
		\setlength{\utlse@openingpicturewidth}{\paperwidth}
		\addtolength{\utlse@openingpicturewidth}{-\bindingwidth}
		\setlength{\utlse@openingbottommargin}{-\bottommargin}
		\addtolength{\utlse@openingbottommargin}{-\footheight}
		\addtolength{\utlse@openingbottommargin}{-\footsep}
		\vfill
		\begin{picture}(0,0)%
			\put(\LenToUnit{-\sidemargin},\LenToUnit{\utlse@openingbottommargin}){\includegraphics[width=\utlse@openingpicturewidth]{#1}}
		\end{picture}%
		\clearpage
	}

	\newlength{\utlse@leftmargin}
	\newcommand{\fullpagepic}[2][]{
		\setlength{\utlse@openingbottommargin}{-\bottommargin}
		\addtolength{\utlse@openingbottommargin}{-\footheight}
		\addtolength{\utlse@openingbottommargin}{-\footsep}
		\setlength{\utlse@leftmargin}{\sidemargin}
		\if@twoside
		\ifthenelse{\isodd{\thepage}}{
			\addtolength{\utlse@leftmargin}{\bindingwidth}
		}{
			\addtolength{\utlse@leftmargin}{\marginparwidth}
			\addtolength{\utlse@leftmargin}{\marginparsep}
		}
		\fi
		\clearpage
		\strut
		\thispagestyle{empty}
		\vfill
		\noindent
		\begin{picture}(0,0)%
			\put(\LenToUnit{-\utlse@leftmargin},\LenToUnit{\utlse@openingbottommargin}){\includegraphics[width=\paperwidth,#1]{#2}}
		\end{picture}%
		\clearpage
	}
}


\setcounter{secnumdepth}{3}
\setcounter{tocdepth}{3}

\clubpenalty=7000
\widowpenalty=7000
\relpenalty=5000
\binoppenalty=5000
%\relpenalty=[number parameter] the parameter speciﬁes the penalty for breaking a math formula after a relation when the formula appears in a paragraph. Plain TEX sets \relpenalty to 500. \binoppenalty=[number parameter] the parameter speciﬁes the penalty for breaking a math formula after a binary operator when the formula appears in a paragraph. Plain TEX sets \binoppenalty to 700

\definecolor{utlsecolor}{rgb}{0,0,0}

\long\def\@makecaption#1#2{%
	\vskip\abovecaptionskip
	\sbox\@tempboxa{\textcolor{utlsecolor}{#1:} #2.}%
	\ifdim \wd\@tempboxa >\hsize
		\textcolor{utlsecolor}{#1:} #2.\par
	\else
		\global \@minipagefalse
		\hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
	\fi
	\vskip\belowcaptionskip
}


\ifthenelse{\boolean{utlse@skin}}{
	\hypersetup{
		linkcolor 	=black,  % color of internal links (sect., pages, ...)
		citecolor 	=black,  % color of citation links (bibliography)
		filecolor 	=black,  % color of file links
		urlcolor 	=black,  % color of URL links (mail, web)
	}

	\ifthenelse{\boolean{utlse@geometry}}{
		\renewcommand{\chapterNumberStyle}[1]{\colorbox{utlsecolor}{\textcolor{white}{#1}}}
	}{
		\setlayout{\inmarginnumbering}{\sidemargin}
		\renewcommand{\chapterNumberStyle}[1]{\colorbox{utlsecolor}{\parbox[t]{.9\sidemargin}{\centering\textcolor{white}{#1}}}}
	}

	\setlength{\chapterrulethickness}{0pt}
	\renewcommand{\partStyle}{\Huge\color{utlsecolor}}
	\renewcommand{\chapterStyle}{\raggedright\Huge}
	\renewcommand{\sectionStyle}{\raggedright\Large\color{utlsecolor}}
	\renewcommand{\subsectionStyle}{\raggedright\large}
	\renewcommand{\subsubsectionStyle}{\raggedright\normalsize}

	\definecolor{utlsecolor}{rgb}{0.75,0.,0.}

	\ifthenelse{\boolean{utlse@nofancy} \or \boolean{utlse@geometry}}{}{
		\definecolor{pagemarkbg}{rgb}{0.75,0.,0.}
		\renewcommand{\pagemarkStyle}{}
		\setlength{\pagemarkWidth}{1cm}
		\renewcommand{\headrulewidth}{.8pt} %%% fancyhdr
	}
}{}

\endinput

%%% utlsethesis quick'n dirty documentation %%%

%  Options:
% This work inherits from LaTeX Book class, and passes its option to it
% so you can provide any book class option you want in the document class declaration.
% It also adds some new option:
%   review		% review mode, extra spaced lines
%   chapterlines	% review must be set, turns on line numbering (by chapter)
%   outernum		% put the chapter number at the right
%   skin		% use a different skin, this is a preset alternative to the default appearance to match the Univerty of Toulouse
			% color scheme
%   chapterbib		% use this option instead of \usepackage{chapterbib} in order to get the preset behavior
			% preset behavior is incompatble with most chapterbib options, so use this class option or chapterbib package
			% but avoid using both at the same time. Note that this option also makes use of the natbib package so you will need
			% to use natbib compatible bibliography styles (such as abrrvnat instead of abbrv, etc)
			% since natbib loading is then done inside the class, you cannot load natbib via usepackage anymore when you use
			% chapterbib class option, so set natbib options via class options too
%   nofancy		% do not use fancyhdr package (disables some commands and sets page style to plain),
			% you are then free to use fancyhdr via usepackage if you only want to avoid default tweakings
%   pagemarks		% only available with fancyhdr, enable page marks by default (use them with \setpagemark{} command)
%   autochaptermark	% automatically set page marks for chapters, when defined in conjunction with pagemarks, you need no
			% explicit use of the \setpagemark{} command anymore (it is still possible though)
%   nat*		% every option accepted by natbib is provided as class option with the same name but preceeded by 'nat', so that you
			% can set natbib options even when it is loaded inside the class
%   geometry		% be compatible with geometry package and alikes. Note that it disables many features.

%  Valid lengths (set them with \setlayout):
% \sidemargin			% margin on page sides (left/right/even/odd)
% \topmargin			% top blank space (on top of header)
% \bottommargin			% bottom blank space (at bottom of footer)
% \headheight			% height of header
% \footheight			% height of footer
% \headsep			% space between header and page content
% \footsep			%               footer
% \marginparwidth		% width of the reserved place for side notes at the outer side of the page (right while one side printing)
% \marginparsep			% space between side notes and page content
% \bindingwidth			% space reserved for binding the document (left while one side printing)
% \chapterrulethickness		% thickness of the rule used for chapter title page decoration
% \inmarginnumbering		% how deep the chapter numbers may penetrate the margin
% \headrulewidth		% available only if using fancyhdr package (no nofancy option)
% Beware that since theses lengths are defined in the document class you should not use the geometry package with this, or it would mess up the layout.
% If you really want to use geometry, add "geometry" option in documentclass call, but it will disable lots of features.

%  Some interesting font:
% \newfont{\chapterNumberFont}{\rmdefault10 at 96pt}

%  Useful commands:
% \setlayout{\sidemargin}{1cm}	% change lengths acting on layout. You should only use this only in the preamble.
% \sidenote{some text}		% write a note in side margin ... beware not to leave \marginparwidth with a null value !!!
% \chapterStyle			% the style you want ! ex: \renewcommand{\chapterStyle}{\Large\sc}
% \chapterNumberStyle		% 
% \partStyle			% 
% \partHeaderStyle		% 
% \sectionStyle			% 
% \subsectionStyle		% 
% \subsubsectionStyle		% 
% \paragraphStyle		% 
% \subparagraphStyle		% 
% \cleanmarks			% Empties page header marks: should always be used instead of \markboth{}{}. When explicitly setting marks you should still
%				% avoid \markboth: use \chaptermark and \sectionmark instead.
%
% \thechaptertitle	% should be self explanatory but works well only for
% \thesectiontitle	% numbered chapters/sections/subsections (not starred)
% \thesubsectiontitle	% available only if using fancyhdr package (no nofancy option)
% \thechapternumber	% 
% \thesectionnumber	% 
% \thesubsectionnumber	% 
%
% \openingpic{filename}		% Use the picture file named "filename" to illustrate chapter titlepages. Use it after anything that should be on the titlepage
% \fullpagepic{filename}	% Include a f picture set to full paper width
%				% as these commands are designed for presentation purpose, they are both ignored in review mode (actually, \fullpagepic only clears page)

%  Abstract environment:
% \begin{abstract}{Summary}	% This environment may be used multiple times (as an example, for abstracts in different languages)
%   % ...			% and may be used for the document abstract as for part or chapter abstract.
% \end{abstract}		% Its parameter is its title

%  Note:
% \part and \part* both appear in table of contents in which they are not numbered 
% but \part are still numbered on their title page
% Chapters numbering is not reset between parts.

%  Marks on page sides:
%  - They are drawn according to different length that can be set by the user:
% \pagemarkHeight	% height (should be enough for all its content to fit in, beware of long titles)
% \pagemarkWidth	% width (should be smaller than the \sidemargin length)
% \pagemarkOffset	% vertical offset (not easy to set, 0pt puts the first mark at the bottom of the header text line)
% \pagemarkBetween	% distance between two marks, if \pagemarkHeight is greater, marks will overlap (usefull, if you have many long marks)
% - They are defined as part of the headers with fancyhdr package:
% If you want to change the header content, use the \pagemarkL and \pagemarkR commands (as shown thereafter).
%   \fancyhf[HOR]{\thepage\pagemarkR}
%   \fancyhf[HEL]{\pagemarkL\thepage}
% Once \pagemarkR and \pagemarkL are included in headers (or pagemarks class option is provided), you can then use these commands:
% \setpagemark{Content}	% enable page marks and set marks' content
% \unsetpagemark	% disable page marks
% pagemark		% counter for the marks, set it to 0 just after calling \setpagemark{} in order to restart positionning marks from the top.

%  Colors:
% pagemarkbg		% page mark background color
% pagemarkfg		% page mark foreground color
% utlsecolor		% color shared by different elements (mostly useful with "skin" class option)
